from textwrap import dedent


def main():
    print(
        dedent(
            """
            The only way you can get good, unless you're a genius, is to copy. That's the best thing. Just steal.
            --Ritchie Blackmore
            """
        ).strip()
    )
